==> haskell-generic-random-1.5.0.1-178-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-KozLM7tFdDYJdS6qhvnZof
key:                  generic-random-1.5.0.1-KozLM7tFdDYJdS6qhvnZof
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  04efe3bc4b421d97f1286c6ddf520dfb
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-random
hs-libraries:         HSgeneric-random-1.5.0.1-KozLM7tFdDYJdS6qhvnZof
depends:
    QuickCheck-2.15.0.1-K2FdhpAloErGP21S0B8fgw base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-random-1.5.0.1-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-90MIFirxXXNBPm1baULaCh
key:                  generic-random-1.5.0.1-90MIFirxXXNBPm1baULaCh
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  1710b5f78cb91eebd15a41686077d901
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-random
hs-libraries:         HSgeneric-random-1.5.0.1-90MIFirxXXNBPm1baULaCh
depends:
    QuickCheck-2.15.0.1-1pOwhmMeliZCxioVyv9M89 base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
